package de.jottyfan.timetrack.spring.contact;

import java.util.List;

import javax.annotation.security.RolesAllowed;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

/**
 * 
 * @author henkej
 *
 */
@Controller
public class ContactController {
	private static final Logger LOGGER = LogManager.getLogger(ContactController.class);

	private final HttpServletRequest request;

	@Autowired
	private IContactService contactService;

	@Autowired
	public ContactController(HttpServletRequest request) {
		this.request = request;
	}

	@GetMapping("/logout")
	public String getLogout(HttpServletRequest request) throws ServletException {
		request.logout();
		return "redirect:/";
	}

	@GetMapping("/")
	public String getIndex() {
		return "public/index";
	}
	
	@ModelAttribute("currentUser")
	@ResponseBody
	public String getCurrentUser() {
		return contactService.getCurrentUser(request);
	}

	@RolesAllowed("timetrack_user")
	@RequestMapping(value = "/contact/contacts")
	public String getList(Model model, @ModelAttribute ContactBean bean) {
		List<ContactBean> list = contactService.toList();
		model.addAttribute("contactList", list);
		return "contact/contacts";
	}

	@RolesAllowed("timetrack_user")
	@RequestMapping(value = "/contact/add/")
	public String toAdd(Model model) {
		return "contact/item";
	}

	@RolesAllowed("timetrack_user")
	@RequestMapping(value = "/contact/insert", method = RequestMethod.POST)
	public String doInsert(Model model, @ModelAttribute ContactBean bean) {
		Integer amount = contactService.doInsert(bean);
		return amount.equals(1) ? "contact/contacts" : "concact/item";
	}

	@RolesAllowed("timetrack_user")
  @GetMapping("/contact/edit/{id}")
	public String toEdit(@PathVariable Integer id, Model model) {
		return "not yet implemented";
	}

	@RolesAllowed("timetrack_user")
	@RequestMapping(value = "/contact/delete/")
	public String doDelete(Model model, @ModelAttribute ContactBean bean) {
		Integer amount = contactService.doDelete(bean.getPk());
		return amount.equals(1) ? "contact/contacts" : "contact/contacts";
	}
}
