package de.jottyfan.timetrack.spring.contact.impl;

import java.util.ArrayList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.jooq.DSLContext;
import org.keycloak.KeycloakSecurityContext;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import de.jottyfan.timetrack.spring.contact.ContactBean;
import de.jottyfan.timetrack.spring.contact.IContactService;

/**
 * 
 * @author henkej
 *
 */
@Service
@Transactional(transactionManager = "transactionManager")
public class ContactService implements IContactService {
	private static final Logger LOGGER = LogManager.getLogger(ContactService.class);

	@Autowired
	private DSLContext dsl;
	
	@Override
  public String getCurrentUser(HttpServletRequest request) {
		KeycloakSecurityContext ksc = (KeycloakSecurityContext) request.getAttribute(KeycloakSecurityContext.class.getName());
		return ksc == null ? "" : ksc.getIdToken().getPreferredUsername();
	}

	@Override
	public List<ContactBean> toList() {
		try {
			return new ContactGateway(dsl).getAll();
		} catch (Exception e) {
			LOGGER.error(e);
			return new ArrayList<>();
		}
	}

	@Override
	public Integer doInsert(ContactBean bean) {
		try {
			return new ContactGateway(dsl).add(bean);
		} catch (Exception e) {
			LOGGER.error(e);
			return 0;
		}
	}

	@Override
	public Integer doUdate(ContactBean bean) {
		try {
			return new ContactGateway(dsl).update(bean);
		} catch (Exception e) {
			LOGGER.error(e);
			return 0;
		}
	}

	@Override
	public Integer doDelete(Integer pk) {
		try {
			return new ContactGateway(dsl).delete(pk);
		} catch (Exception e) {
			LOGGER.error(e);
			return 0;
		}
	}

	@Override
	public Integer getAmount() {
		return toList().size();
	}
}
